@@ -8,5 +8,3 @@ fi
 ( cd usr/X11R6/lib ; ln -sf ../../lib/pkgconfig pkgconfig )
 ( cd usr/include ; rm -rf GL )
 ( cd usr/include ; ln -sf /usr/X11R6/include/GL GL )
-( cd usr/include ; rm -rf freetype )
-( cd usr/include ; ln -sf freetype2/freetype freetype )
